Appendix B: API Reference
#########################

.. include:: includes/zope2_notice.rst

Introduction
============

This reference describes the interfaces to the most common set of basic Zope
objects. This reference is useful while writing Page Templates, DTML, Python
scripts, and Product code.

The intended audience is able to read simple Python code and has at least
passing experience with object-oriented programming.

The reference is not a tutorial. Nor is it a substitute for reading the rest of
the Zope Book. Examples, where they are provided, are intended to be
illustrative, but not comprehensive.

Sorry
=====

The manually maintained API reference wasn't such a good idea.

Converting it from the original source of structured text to reStructuredText
was too much work to be done. We will look into auto-generating the API
documentation from docstrings at some point.

Reading the code is your best bet for now.
